@@ -253,6 +253,8 @@ static void syntax(const char *msg, int thisLine)
     exit(1);
 }
 
+#pragma GCC diagnostic push
+#pragma GCC diagnostic ignored "-Wcast-align"
 static void get_env_conf(void)
 {
     char *s;
@@ -262,11 +264,9 @@ static void get_env_conf(void)
 	s = getenv(global_switches[i].name);
 	if(s) {
 	    errno = 0;
-#pragma GCC diagnostic push
-#pragma GCC diagnostic ignored "-Wcast-align"
 	    switch(global_switches[i].type) {
 	    case T_INT:
-		* ((int *)global_switches[i].address) = strtoi(s,0,0);
+		* ((int *)global_switches[i].address) = strtosi(s,0,0);
 		break;
 	    case T_UINT:
 		* ((unsigned int *)global_switches[i].address) = strtoui(s,0,0);
@@ -282,7 +282,6 @@ static void get_env_conf(void)
 		* ((char **)global_switches[i].address) = s;
 		break;
 	    }
-#pragma GCC diagnostic pop
 	    if(errno != 0) {
 		fprintf(stderr, "Bad number %s for %s (%s)\n", s,
 			global_switches[i].name,
@@ -292,6 +291,7 @@ static void get_env_conf(void)
 	}
     }
 }
+#pragma GCC diagnostic pop
 
 static int mtools_getline(void)
 {
@@ -505,6 +505,8 @@ static void finish_drive_clause(void)
     cur_dev = -1;
 }
 
+#pragma GCC diagnostic push
+#pragma GCC diagnostic ignored "-Wcast-align"
 static int set_var(struct switches_l *switches, int nr,
 		   caddr_t base_address)
 {
@@ -512,8 +514,6 @@ static int set_var(struct switches_l *switches, int nr,
     for(i=0; i < nr; i++) {
 	if(match_token(switches[i].name)) {
 	    expect_char('=');
-#pragma GCC diagnostic push
-#pragma GCC diagnostic ignored "-Wcast-align"
 	    /* All pointers cast back to pointers with alignment
 	     * constraints were such pointers with alignment
 	     * constraints initially, thus they do indeed fit the
@@ -537,12 +537,12 @@ static int set_var(struct switches_l *switches, int nr,
 	    else if (switches[i].type == T_UQSTRING)
 		* ((char**)((long)switches[i].address+base_address))=
 		    get_unquoted_string();
-#pragma GCC diagnostic pop
 	    return 0;
 	}
     }
     return 1;
 }
+#pragma GCC diagnostic pop
 
 static int set_openflags(struct device *dev)
 {
@@ -655,7 +655,7 @@ void check_number_parse_errno(char c, const char *oarg, char *endptr) {
 }
 
 static uint16_t tou16(int in, const char *comment) {
-    if(in > UINT16_MAX) {
+    if(in > (int) UINT16_MAX) {
 	fprintf(stderr, "Number of %s %d too big\n", comment, in);
 	exit(1);
     }
